# Storey

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**building_id** | **str** |  | [optional] [readonly] 
**name** | **str** |  | 
**elevation** | **float** |  | [optional] 
**order** | **int** |  | [optional] [readonly] 
**models** | [**list[ModelWithPositioningPlan]**](ModelWithPositioningPlan.md) |  | [optional] [readonly] 
**models_unreachable_count** | **int** |  | [optional] [readonly] 
**is_site** | **bool** |  | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


